@@ -25,7 +25,7 @@ def return_mainscreen_threaded_statistics():
     for indx in cputimes:
         timelist.append(
             (
-                cpuindex,
+                cpuindex + 1,
                 indx.user,
                 indx.nice,
                 indx.system,
